The ONC Python client library contains a number of classes and functions that access Ocean Networks Canada data through the Oceans 2.0 API.

Official documentation:
https://wiki.oceannetworks.ca/display/O2A/Oceans+2.0+API+Home